==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/circles/l10n/vi.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Vòng kết nối",
    "Circles' files" : "Tệp tin của các vòng kết nối",
    "Select circles to filter by" : "Chọn các vòng kết nối để lọc bởi",
    "No circles found" : "Không có vòng kết nối được tìm thấy",
    "Please select circles to filter by" : "Vui lòng chọn các vòng kết nối để lọc bởi",
    "No files found for the selected circles" : "Không có tệp được tìm thấy cho vòng kết nối được chọn",
    "You created the circle {circle}" : "Bạn đã tạo một vòng kết nối {circle}",
    "{author} created the circle {circle}" : "{author} đã tạo một vòng kết nối {circle}",
    "You deleted {circle}" : "Bạn đã xóa {circle}",
    "{author} deleted {circle}" : "{author} đã xóa {circle}",
    "You linked {group} to {circle}" : "Bạn đã liên kết {group} đến {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} vừa mới được liên kết đến {circle } bởi {author}",
    "You unlinked {group} from {circle}" : " Bạn đã hủy liên kết {group} từ {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} vừa mới được hủy liên kết từ {circle} bởi {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Bạn đã thay đổi cấp độ của nhóm được liên kết {group} trong {circle} ở mức %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} đã thay đổi cấp độ của nhóm được liên kết {group} trong {circle} ở mức %1$s",
    "You sent a request to link {circle} with {remote}" : "Bạn đã gửi 1 yêu cầu để liên kết {circle} với {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} gửi một yêu cầu để liên kết {circle} với {remote}",
    "{remote} requested a link with {circle}" : "{remote} đã yêu cầu một liên kết với {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Các yêu cầu để liên kết {circle} với {remote} đã bị từ chối",
    "The request to link {remote} with {circle} has been canceled remotely" : "Yêu cầu để liên kết {remote} với {circle} đã bị hủy bỏ từ xa",
    "The request to link {circle} with {remote} has been accepted" : "Yêu cầu để liên kết {circle} với {remote} đã được chấp thuận",
    "You dismissed the request to link {remote} with {circle}" : "Bạn đã bỏ qua yêu cầu liên kết {remote} với {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} đã bỏ qua yêu cầu liên kết {remote} với {circle}",
    "You canceled the request to link {circle} with {remote}" : "Bạn đã hủy yêu cầu liên kết {circle} với {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} đã hủy yêu cầu liên kết {circle} với {remote}",
    "You accepted the request to link {remote} with {circle}" : "Bạn đã chấp thuận yêu cầu liên kết {remote} với {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} đã chấp thuận yêu cầu liên kết {remote} với {circle}",
    "A link between {circle} and {remote} is now up and running" : "Một liên kết giữa {circle} và {remote} bây giờ đã khả dụng và đang chạy",
    "The link between {circle} and {remote} has been shutdown remotely" : "Một liên kết giữa {circle} và {remote} đã được tắt từ xa",
    "You closed the link between {circle} and {remote}" : "Bạn đã đóng liên kết giữ {circle} và {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} đã đóng liên kết giữa {circle} và {remote}",
    "You joined {circle}" : "Bạn đã gia nhập {circle}",
    "{member} joined {circle}" : "{nember} đã gia nhập {circle}",
    "You accepted the invitation to join {circle}" : "Bạn đã chấp thuận lời mời để gia nhập {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} đã chấp thuận lời mời để gia nhập {circle}",
    "You added {member} as member to {circle}" : "Bạn đã thêm {member} với tư cách là thành viên của {circle}",
    "You have been added as member to {circle} by {author}" : "Bạn đã được thêm vào nhóm {circle} với tư cách là thành viên bởi {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} đã được thêm với tư cách là thành viên vào {circle} bởi {author}",
    "You added {external} to {circle}" : "Bạn đã thêm {external} vào {circle}",
    "{external} has been added to {circle} by {author}" : "{externa} vừa mới được thêm vào {circle} bởi {author}",
    "You accepted {member}'s request to join {circle}" : "Bạn đã chấp thuận yêu cầu liên kết của {member} để gia nhập {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập {circle} của bạn đã được chấp thuận bởi {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập của {member} vào {circle} vừa mới được chấp thuận bởi {author}",
    "You left {circle}" : "Bạn đã rời bỏ {circle}",
    "{member} left {circle}" : "{member} đã rời bỏ {circle}",
    "You declined the invitation to join {circle}" : "Bạn đã từ chối lời mời gia nhập vào {circle}",
    "{member} declined an invitation to join {circle}" : "{member} đã từ chối một lời mời gia nhập vào {circle}",
    "You cancelled your request to join {circle}" : "Bạn đã hủy bỏ yêu cầu của bạn để gia nhập {circle}",
    "{member} cancelled his request to join {circle}" : "{member} đã hủy bỏ yêu cầu của anh/chị ấy để gia nhập vào {circle}",
    "You removed {member} from {circle}" : "Bạn đã gỡ bỏ {member} ra khỏi {circle}",
    "You have been removed from {circle} by {author}" : "Bạn vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "{member} has been removed from {circle} by {author}" : "{member} vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "You removed {external} from {circle}" : "Bạn gỡ bỏ {external} khỏi {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} vừa mới được gỡ bỏ khỏi {circle} bởi {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Bạn đã hủy lời mời gia nhập vào {circle} của thành viên {member}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Lời mời gia nhập vào {circle} của bạn đã bị hủy bỏ bởi {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} đã hủy bỏ lời mời tham gia vào nhóm {circle} của {member} ",
    "You dismissed {member}'s request to join {circle}" : "Bạn đã bỏ qua yêu cầu gia nhập vào {circle} của {member}",
    "Your request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của bạn đã bị bỏ qua bởi {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của {member} đã bị bỏ qua bởi {author}",
    "You invited {member} to join {circle}" : "Bạn đã mời {member} để gia nhập vào {circle}",
    "You have been invited to join {circle} by {author}" : "Bạn vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Bạn đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của bạn trong {circle} ở mức %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "You sent a request to join {circle}" : "Bạn đã gửi một yêu cầu để gia nhập {circle}",
    "{member} sent a request to join {circle}" : "{member} đã gửi một yêu cầu để gia nhập {circle}",
    "You are the new owner of {circle}" : "Bạn là chủ nhân mới của {circle}",
    "{member} is the new owner of {circle}" : "{member} là chủ nhân mới của {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Trên những sự kiên đang diễn ra trong một <strong> Vòng kết nối </strong> mà bạn là thành viên của nhóm",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Một sự kiện quan trọng trong một <strong> Vòng kết nối </strong> mà bạn đang điều hành",
    "On global events happening in any <strong>Circle</strong>" : "Trên những sự kiện chung đang diễn ra của tổ chức trong bất cứ <strong> Vòng kết nối </strong>",
    "Shared to Circles" : "Đã được chia sẻ đến những Vòng kết nối",
    "Single" : "Riêng lẻ",
    "Personal" : "Cá nhân",
    "System" : "Hệ thống",
    "Visible" : "Có thể nhìn thấy",
    "Open" : "Mở",
    "Invite" : "Mời",
    "Join Request" : "Yêu cầu tham gia",
    "Friends" : "Bạn bè",
    "Password Protected" : "Được bảo vệ mật khẩu",
    "No Owner" : "Không có chủ sở hữu",
    "Hidden" : "Ẩn",
    "Backend" : "Backend",
    "Local" : "Cục bộ(ngoại tuyến)",
    "Root" : "Gốc",
    "Circle Invite" : "Mời vòng kết nối",
    "Federated" : "Federated",
    "Mount point" : "Điểm gắn",
    "Nextcloud Account" : "Tài khoản Nextcloud",
    "Nextcloud Group" : "Nhóm Nextcloud",
    "Email Address" : "Địa chỉ email",
    "Contact" : "Liên hệ",
    "Circle" : "Vòng kết nối",
    "Nextcloud App" : "Ứng dụng Nextcloud",
    "Member" : "Thành viên",
    "Moderator" : "Kiểm duyệt",
    "Admin" : "Quản trị",
    "Owner" : "Chủ",
    "%s shared »%s« with you." : "%s đã chia sẻ »%s« với bạn",
    "%s shared »%s« with \"%s\"." : "%s đã chia sẻ »%s« với \"%s\".",
    "%s on %s" : "%s trên %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s đã chia sẻ »%2$s« với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập nó.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s đã chia sẻ »%2$s« với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập nó.",
    "Password to access »%1$s« shared to you by %2$s" : "Mật khẩu để truy cập »%1$s« đã được chia sẻ tới bạn bởi %2$s",
    "Password to access »%s«" : "Mật khẩu để truy cập »%s«",
    "It is protected with the following password:" : "Nó được bảo vệ bởi mật khẩu sau đây:",
    "%1$s via %2$s" : "%1$s thông qua %2$s",
    "Click the button below to open it." : "Bấm vào nút bên dưới để mở nó.",
    "Open »%s«" : "Mở »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s đã chia sẻ nhiều tệp tin với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập chúng.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s đã chia sẻ nhiều tệp tin với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập chúng.",
    "Password to access files shared to you by %1$s" : "Mật khẩu để truy cập vào các tệp đã được chia sẻ tới bạn bởi %1$s",
    "Password to access files" : "Mật khẩu để truy cập các tệp",
    "%s shared multiple files with \"%s\"." : "%s đã chia sẻ nhiều tệp với \"%s\".",
    "%s shared multiple files with you." : "%s đã chia sẻ tổ hợp tệp với bạn.",
    "Boot up" : "Khởi động lên",
    "Nextcloud Initialization" : "Khởi tạo Nextcloud",
    "Circles App Initialization" : "Khởi tạo Ứng dụng vòng kết nối",
    "Fresh installation status" : "Trạng thái cài đặt mới",
    "Building Local Database" : "Đang xây dựng cơ sở dữ liệu cục bộ",
    "Testing Basic Circle Creation" : "Đang kiểm tra Tạo vòng kết nối cơ bản",
    "Adding local users and moderators" : "Đang thêm người dùng và người quản lý",
    "Circle not found" : "Vòng kết nối không được tìm thấy",
    "Circle not found " : "Vòng kết nối không được tìm thấy",
    "This member does not exist" : "Thành viên này không tồn tại",
    "This account is already a member of the circle" : "Tài khoản này đã là thành viên của Vòng kết nối",
    "Federated link not found" : "Liên kết Liên Bang không thể được tìm thấy",
    "This feature is not available for personal circles" : "Tính năng này không khả dụng cho các vòng kết nối cá nhân",
    "The circle is not federated" : "Vòng kết nối không được chia sẻ liên bang",
    "You cannot join this circle" : "Bạn không thể tham gia vòng kết nối này",
    "This member is not a moderator" : "Thành viên này không phải là người điều hành",
    "Insufficient privileges" : "Không đủ các quyền hạn",
    "This member is the owner of the circle" : "Thành viên này là chủ nhân của vòng kết nối",
    "Level cannot be changed for this type of member" : "Cấp độ không thể được thay đổi cho kiểu loại của thành viên này",
    "You are already a member of this circle" : "Bạn đã là thành viên của vòng kết nối này",
    "You have been blocked from this circle" : "Bạn đã bị chặn khỏi vòng kết nối này",
    "The account is already a member of this circle" : "Tài khoản này đã là thành viên của Vòng kết nối này",
    "The account has already been invited into this circle" : "Tài khoản này đã được mời vào Vòng kết nối này",
    "%s (Circle owned by %s)" : "%s (Vòng kết nối được sở hữu bởi %s)",
    "You are now a member of the Circle \"%2$s\"" : "Bây giờ bạn là thành viên của Vòng kết nối \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Bạn vừa mới được mời bởi %1$s vào Vòng kết nối \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s đã gửi một yêu cầu để là một thành viên của Vòng kết nối \"%2$s\"",
    "Accept" : "Đồng ý",
    "Refuse" : "Từ chối",
    "Leave the circle" : "Rời bỏ vòng kết nối",
    "%s" : "%s",
    "Personal Circle" : "Vòng cá nhân",
    "%s owned by %s" : "%s được sở hữu bởi %s",
    "You need a specify a type of circle" : "Bạn cần xác định một kiểu loại của vòng kết nối",
    "A circle with that name exists" : "Đã tồn tại một vòng kết nối có tên đó",
    "This member is not the owner of the circle" : "Thành viên này không phải là chủ nhân của vòng kết nối",
    "This member is not an admin of the circle" : "Thành viên này không phải là một quản trị viên của vòng kết nối này",
    "Group contains too many members" : "Nhóm chứa quá nhiều thành viên",
    "This group does not exist" : "Nhóm này không tồn tại",
    "This group is already linked to the circle" : "Nhóm này đã được liên kết tới vòng kết nối",
    "You cannot edit level in a personal circle" : "Bạn không thể sửa đổi mức độ trong một vòng kết nối cá nhân",
    "Group cannot be set as owner of a circle" : "Nhóm không thể được đặt với tư cách là chủ nhận của một vòng kết nối",
    "now" : "bây giờ",
    "This account does not exist" : "Tài khoản này không tồn tại",
    "Email format is not valid" : "Định dạng thư điện tử không hợp lệ",
    "This contact is not available" : "Liên hệ này không khả dụng",
    "You have no permission to create a new circle" : "Bạn không có quyền để tạo vòng kết nối mới",
    "%s shared a file with \"%s\"." : "%s đã chia sẻ một tệp tin với \"%s\".",
    "%s shared a file with you." : "%s đã chia sẻ một tệp tin với bạn.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s đã chia sẻ một vài nội dung với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập chúng.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s đã chia sẻ một vài nội dung với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập chúng.",
    "Password to access content shared with you by %1$s" : "Mật khẩu để truy cập nội dung được chia sẻ với bạn bởi %1$s",
    "Password to access content" : "Mật khẩu để truy cập nội dung",
    "This item is already shared with this circle" : "Mục này đã được chia sẻ với vòng kết nối này",
    "Bring cloud-users closer together." : "Mang các người dùng-điện toán đám mây đến gần nhau hơn",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Vòng kết nối cho phép mọi người tạo nhóm người/đồng nghiệp/bạn bè của riêng họ.\nNhững nhóm người đó (hoặc \"vòng kết nối\") sau đó có thể được bất kỳ ứng dụng nào khác sử dụng cho mục đích chia sẻ.",
    "No files in here" : "Không có tệp ở đây",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "Initialisation Nextcloud" : "Khởi tạo Nextcloud",
    "Initialisation Circles App" : "Khởi tạo Ứng dụng vòng kết nối"
},
"nplurals=1; plural=0;");

==> php83-nextcloud-30.0.15.tgz: share/nextcloud/apps/circles/l10n/vi.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Bạn đã xóa {circle}",
    "{author} deleted {circle}" : "{author} đã xóa {circle}",
    "You removed {member} from {circle}" : "Bạn đã gỡ bỏ {member} ra khỏi {circle}",
    "You joined {circle}" : "Bạn đã gia nhập {circle}",
    "{member} joined {circle}" : "{nember} đã gia nhập {circle}",
    "You accepted the invitation to join {circle}" : "Bạn đã chấp thuận lời mời để gia nhập {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} đã chấp thuận lời mời để gia nhập {circle}",
    "You added {member} as member to {circle}" : "Bạn đã thêm {member} với tư cách là thành viên của {circle}",
    "You have been added as member to {circle} by {author}" : "Bạn đã được thêm vào nhóm {circle} với tư cách là thành viên bởi {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} đã được thêm với tư cách là thành viên vào {circle} bởi {author}",
    "You added {external} to {circle}" : "Bạn đã thêm {external} vào {circle}",
    "{external} has been added to {circle} by {author}" : "{externa} vừa mới được thêm vào {circle} bởi {author}",
    "You accepted {member}'s request to join {circle}" : "Bạn đã chấp thuận yêu cầu liên kết của {member} để gia nhập {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập {circle} của bạn đã được chấp thuận bởi {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập của {member} vào {circle} vừa mới được chấp thuận bởi {author}",
    "You left {circle}" : "Bạn đã rời bỏ {circle}",
    "{member} left {circle}" : "{member} đã rời bỏ {circle}",
    "You declined the invitation to join {circle}" : "Bạn đã từ chối lời mời gia nhập vào {circle}",
    "{member} declined an invitation to join {circle}" : "{member} đã từ chối một lời mời gia nhập vào {circle}",
    "You cancelled your request to join {circle}" : "Bạn đã hủy bỏ yêu cầu của bạn để gia nhập {circle}",
    "You have been removed from {circle} by {author}" : "Bạn vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "{member} has been removed from {circle} by {author}" : "{member} vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "You removed {external} from {circle}" : "Bạn gỡ bỏ {external} khỏi {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} vừa mới được gỡ bỏ khỏi {circle} bởi {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Bạn đã hủy lời mời gia nhập vào {circle} của thành viên {member}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Lời mời gia nhập vào {circle} của bạn đã bị hủy bỏ bởi {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} đã hủy bỏ lời mời tham gia vào nhóm {circle} của {member} ",
    "You dismissed {member}'s request to join {circle}" : "Bạn đã bỏ qua yêu cầu gia nhập vào {circle} của {member}",
    "Your request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của bạn đã bị bỏ qua bởi {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của {member} đã bị bỏ qua bởi {author}",
    "You invited {member} to join {circle}" : "Bạn đã mời {member} để gia nhập vào {circle}",
    "You have been invited to join {circle} by {author}" : "Bạn vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Bạn đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của bạn trong {circle} ở mức %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "You sent a request to join {circle}" : "Bạn đã gửi một yêu cầu để gia nhập {circle}",
    "{member} sent a request to join {circle}" : "{member} đã gửi một yêu cầu để gia nhập {circle}",
    "You are the new owner of {circle}" : "Bạn là chủ nhân mới của {circle}",
    "{member} is the new owner of {circle}" : "{member} là chủ nhân mới của {circle}",
    "Single" : "Riêng lẻ",
    "Personal" : "Cá nhân",
    "System" : "Hệ thống",
    "Visible" : "Có thể nhìn thấy",
    "Open" : "Mở",
    "Invite" : "Mời",
    "Friends" : "Bạn bè",
    "Password protected" : "Mật khẩu bảo vệ",
    "No Owner" : "Không có chủ sở hữu",
    "Hidden" : "Ẩn",
    "Backend" : "Backend",
    "Local" : "Cục bộ(ngoại tuyến)",
    "Root" : "Gốc",
    "Federated" : "Federated",
    "Mount point" : "Điểm gắn",
    "Nextcloud Account" : "Tài khoản Nextcloud",
    "Nextcloud Group" : "Nhóm Nextcloud",
    "Email address" : "Địa chỉ thư điện tử",
    "Contact" : "Liên hệ",
    "Nextcloud App" : "Ứng dụng Nextcloud",
    "Member" : "Thành viên",
    "Moderator" : "Kiểm duyệt",
    "Admin" : "Quản trị",
    "Owner" : "Chủ",
    "%s shared »%s« with you." : "%s đã chia sẻ »%s« với bạn",
    "%s shared »%s« with \"%s\"." : "%s đã chia sẻ »%s« với \"%s\".",
    "%s on %s" : "%s trên %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s đã chia sẻ »%2$s« với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập nó.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s đã chia sẻ »%2$s« với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập nó.",
    "Password to access »%1$s« shared to you by %2$s" : "Mật khẩu để truy cập »%1$s« đã được chia sẻ tới bạn bởi %2$s",
    "Password to access »%s«" : "Mật khẩu để truy cập »%s«",
    "It is protected with the following password:" : "Nó được bảo vệ bởi mật khẩu sau đây:",
    "%1$s via %2$s" : "%1$s thông qua %2$s",
    "Click the button below to open it." : "Bấm vào nút bên dưới để mở nó.",
    "Open »%s«" : "Mở »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s đã chia sẻ nhiều tệp tin với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập chúng.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s đã chia sẻ nhiều tệp tin với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập chúng.",
    "Password to access files shared to you by %1$s" : "Mật khẩu để truy cập vào các tệp đã được chia sẻ tới bạn bởi %1$s",
    "Password to access files" : "Mật khẩu để truy cập các tệp",
    "%s shared multiple files with \"%s\"." : "%s đã chia sẻ nhiều tệp với \"%s\".",
    "%s shared multiple files with you." : "%s đã chia sẻ tổ hợp tệp với bạn.",
    "Boot up" : "Khởi động lên",
    "Nextcloud Initialization" : "Khởi tạo Nextcloud",
    "Circles App Initialization" : "Khởi tạo Ứng dụng vòng kết nối",
    "Fresh installation status" : "Trạng thái cài đặt mới",
    "Building Local Database" : "Đang xây dựng cơ sở dữ liệu cục bộ",
    "Testing Basic Circle Creation" : "Đang kiểm tra Tạo vòng kết nối cơ bản",
    "Adding local users and moderators" : "Đang thêm người dùng và người quản lý",
    "Files" : "Tệp tin",
    "This feature is not available for personal circles" : "Tính năng này không khả dụng cho các vòng kết nối cá nhân",
    "This member is not a moderator" : "Thành viên này không phải là người điều hành",
    "Insufficient privileges" : "Không đủ các quyền hạn",
    "This member does not exist" : "Thành viên này không tồn tại",
    "Level cannot be changed for this type of member" : "Cấp độ không thể được thay đổi cho kiểu loại của thành viên này",
    "You are already a member of this circle" : "Bạn đã là thành viên của vòng kết nối này",
    "You have been blocked from this circle" : "Bạn đã bị chặn khỏi vòng kết nối này",
    "The account is already a member of this circle" : "Tài khoản này đã là thành viên của Vòng kết nối này",
    "The account has already been invited into this circle" : "Tài khoản này đã được mời vào Vòng kết nối này",
    "Accept" : "Đồng ý",
    "Refuse" : "Từ chối",
    "%s" : "%s",
    "%s owned by %s" : "%s được sở hữu bởi %s",
    "%s shared a file with \"%s\"." : "%s đã chia sẻ một tệp tin với \"%s\".",
    "%s shared a file with you." : "%s đã chia sẻ một tệp tin với bạn.",
    "Open %s" : "Mở trong %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s đã chia sẻ một vài nội dung với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập chúng.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s đã chia sẻ một vài nội dung với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập chúng.",
    "Password to access content shared with you by %1$s" : "Mật khẩu để truy cập nội dung được chia sẻ với bạn bởi %1$s",
    "Password to access content" : "Mật khẩu để truy cập nội dung",
    "Bring cloud-users closer together." : "Mang các người dùng-điện toán đám mây đến gần nhau hơn",
    "Try again" : "Thử lại",
    "Loading…" : "Đang tải…",
    "No files in here" : "Không có tệp ở đây",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "Shared to Circles" : "Đã được chia sẻ đến những Vòng kết nối",
    "Circle" : "Vòng kết nối"
},
"nplurals=1; plural=0;");
